"""Add `rasa_environment` column to `conversation_event` table.

Reason:
The Pika event consumer now consumes events from all environments. In order to keep
track of an event's origin we add a new column to the `conversation_event` table.

This new column `rasa_environment` stores the `app_id` message property of any incoming
RabbitMQ event.

Revision ID: a86c9fac00fa
Revises: 3b15f8e56784

"""

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
from rasax.community.constants import DEFAULT_RASA_ENVIRONMENT

revision = "a86c9fac00fa"
down_revision = "3b15f8e56784"
branch_labels = None
depends_on = None

COLUMN_NAME = "rasa_environment"
TABLE_NAME = "conversation_event"


def upgrade():
    with op.batch_alter_table(TABLE_NAME) as batch_op:
        batch_op.add_column(
            sa.Column(COLUMN_NAME, sa.String(), default=DEFAULT_RASA_ENVIRONMENT)
        )


def downgrade():
    with op.batch_alter_table(TABLE_NAME) as batch_op:
        batch_op.drop_column(COLUMN_NAME)
